# Flatmake
<p align="center">

<a href="https://pypi.python.org/pypi/flatmake">
<img src="https://img.shields.io/pypi/v/flatmake.svg" /></a>
<a href="https://travis-ci.org/dweemx/flatmake"><img src="https://travis-ci.org/dweemx/flatmake.svg?branch=master" /></a>
</p>
A variety of utilities to build high-level flatbuffers structures

## Data Types
- FloatArray
- ColorArray1D
- RGBTripleArray
- Coordinates2D

# Credits
This package was created with Cookiecutter and the `cs01/cookiecutter-pypackage` project template.

[Cookiecutter](https://github.com/audreyr/cookiecutter)

[cs01/cookiecutter-pypackage](https://github.com/cs01/cookiecutter-pypackage)
